@@ -7,10 +7,10 @@ fn main() {
     )
     .unwrap();
 
-    if !std::env::var("CARGO_FEATURE_DOC").is_ok() {
+    if std::env::var("DOCS_RS").is_err() {
         let ortools_prefix = std::env::var("ORTOOLS_PREFIX")
             .ok()
-            .unwrap_or("/opt/ortools".into());
+            .unwrap_or_else(|| "/opt/ortools".into());
         cc::Build::new()
             .cpp(true)
             .flag("-std=c++17")
